#compile megalope uCT data for many megalope scanned in a single vial and compare to environmental variables.
#NOTE: That the diel vertical migration netcdf files required to run this script can be requested from saengec@wwu.edu or emilyln@uw.edu
#The author apologizes for his poor scripting skills. You will also need to change the directories to match the file locations.

setwd("/Volumes/GoogleDrive/My Drive/WWU_GD/R_documents/megalope");

library(leaps)
library(oce)
library(ocedata)
library(corrplot)
library(FreqProf)
library(ncdf4)
library(stats)
library(akima)
library(MuMIn)
data("coastlineWorldFine")

#in situ environmental data collected on 2016 WCOA cruise.
env.dat<-read.csv("/Volumes/GoogleDrive/My Drive/WWU_GD/R_documents/megalope/WestCoastOA2016subset.csv",header=T)

#DVM30 and DVM60 from Norton et al., 2020
DVM30nc<-nc_open("output_2016_v1_DVM_30mDVM_WCOA.nc")
DVM60nc<-nc_open("output_2016_v1_DVM_60mDVM_WCOA.nc")

stn<-c(94,99,100,106,114,115,120,127,130)						#stations with uCT data
stn.nina<-c(94,90,99,100,106,109,115,128)						#stations in Bednarsek et al., 2020
GS<-c(14.61,15.72,16.83,14.64,15.47,16.14,14.88,13.93,15.2)		#greyscale values. See StandardCalibration.xlsx
dist2land<-c(46.45,32.71,44.72,49.21,3.72,6.64,54.93,46.21,6.72)

#initialize some empty data frames. 
env.dat.int30<-data.frame(matrix(,ncol=17))
env.dat.D30<-data.frame(matrix(,ncol=17))
env.dat.max30<-data.frame(matrix(,ncol=17))
env.dat.min30<-data.frame(matrix(,ncol=17))
names(env.dat.int30)<-names(env.dat)
names(env.dat.D30)<-names(env.dat)
names(env.dat.max30)<-names(env.dat)
names(env.dat.min30)<-names(env.dat)

env.dat.int60<-data.frame(matrix(,ncol=17))
env.dat.D60<-data.frame(matrix(,ncol=17))
env.dat.max60<-data.frame(matrix(,ncol=17))
env.dat.min60<-data.frame(matrix(,ncol=17))
names(env.dat.int60)<-names(env.dat)
names(env.dat.D60)<-names(env.dat)
names(env.dat.max60)<-names(env.dat)
names(env.dat.min60)<-names(env.dat)

env.dat.DVM30<-data.frame(matrix(,ncol=33))
env.dat.DVM60<-data.frame(matrix(,ncol=33))
env.dat.moltDVM30<-data.frame(matrix(,ncol=25))
env.dat.moltDVM60<-data.frame(matrix(,ncol=25))

pal<-c("blue","gold2","dodgerblue2","dodgerblue4","cyan","cyan3","blue3","blue4","cyan2")
sym<-c(15,15,16,17,16,17,18,16,18)
sym2=c(0,0,1,2,1,2,5,1,5)

for(i in 1:length(stn)) {
	tmp<-env.dat[which(env.dat$Sta==stn[i]),]
	tmp$ChlA[1:nrow(tmp)]<-mean(tmp$ChlA,na.rm=T)
	tmp<-tmp[-which(is.na(tmp$SILCAT)==T),]
	top30<-tmp[which(tmp$Depth<=31),]					#upper 30m
	D30<-top30[nrow(top30),]-top30[1,]					#difference between surface and 30m
	max30<-apply(top30,2,max)							#max value for each column
	min30<-apply(top30,2,min)							#min value for each column
	int30<-colMeans(approxm(top30,4))					#mean in upper 30
	top60<-tmp[which(tmp$Depth<=61),]					#upper 60m	
	#difference between surface and 60m. If max depth <60 (true at stn 114 and 130), use value at max depth
	D60<-top60[nrow(top60),]-top60[1,]					
	max60<-apply(top60,2,max)							#max value for each column
	min60<-apply(top60,2,min)							#min value for each column
	int60<-colMeans(approxm(top60,7))									#interpolate to have same number of n. Take mean in upper 60
	
	env.dat.int30<-rbind(env.dat.int30,int30)
	env.dat.D30<-rbind(env.dat.D30,D30)
	env.dat.max30<-rbind(env.dat.max30,max30)
	env.dat.min30<-rbind(env.dat.min30,min30)
	env.dat.int60<-rbind(env.dat.int60,int60)
	env.dat.D60<-rbind(env.dat.D60,D60)
	env.dat.max60<-rbind(env.dat.max60,max60)
	env.dat.min60<-rbind(env.dat.min60,min60)
}

#remove first row, which is all NA
env.dat.int30<-env.dat.int30[-c(1),]
env.dat.D30<-env.dat.D30[-c(1),]
env.dat.max30<-env.dat.max30[-c(1),]
env.dat.min30<-env.dat.min30[-c(1),]
env.dat.reduced30<-cbind(env.dat.int30,env.dat.D30,env.dat.max30,env.dat.min30)
env.dat.reduced30<-env.dat.reduced30[,-c(18,19,20,21,33,35,36,37,38,50,52,53,54,55,67)]		#remove redundant columns

env.dat.int60<-env.dat.int60[-c(1),]
env.dat.D60<-env.dat.D60[-c(1),]
env.dat.max60<-env.dat.max60[-c(1),]
env.dat.min60<-env.dat.min60[-c(1),]
env.dat.reduced60<-cbind(env.dat.int60,env.dat.D60,env.dat.max60,env.dat.min60)
env.dat.reduced60<-env.dat.reduced60[,-c(18,19,20,21,33,35,36,37,38,50,52,53,54,55,67)]		#remove redundant columns

#environmental data for calibrations including integrated and delta values over 2 depth ranges.
names(env.dat.reduced30)<-c("Sta","Lat","Long","Depth","T30","S30","DO30","SIL30","NIT30","PHS30","TC30","ALK30","CO330",
	"pHin30","OmegaC30","ChlA30","pCO230","DT30","DS30","DDO30","DSIL30","DNIT30","DPHS30","DTC30","DALK30",
	"DCO330","DpHin30","DOmegaC30","DpCO230","mxT30","mxS30","mxDO30","mxSIL30","mxNIT30","mxPHS30","mxTC30","mxALK30",
	"mxCO330","mxpHin30","mxOmegaC30","mxpCO230","mnT30","mnS30","mnDO30","mnSIL30","mnNIT30","mnPHS30","mnTC30","mnALK30",
	"mnCO330","mnpHin30","mnOmegaC30","mnpCO230")
names(env.dat.reduced60)<-c("Sta","Lat","Long","Depth","T60","S60","DO60","SIL60","NIT60","PHS60","TC60","ALK60","CO360",
	"pHin60","OmegaC60","ChlA60","pCO260","DT60","DS60","DDO60","DSIL60","DNIT60","DPHS60","DTC60",
	"DALK60","DCO360","DpHin60","DOmegaC60","DpCO260","mxT60","mxS60","mxDO60","mxSIL60","mxNIT60","mxPHS60","mxTC60","mxALK60",
	"mxCO360","mxpHin60","mxOmegaC60","mxpCO260","mnT60","mnS60","mnDO60","mnSIL60","mnNIT60","mnPHS60","mnTC60","mnALK60",
	"mnCO360","mnpHin60","mnOmegaC60","mnpCO260")

#reduce a little more
env.dat.reduced30<-subset(env.dat.reduced30, select=-c(SIL30, DDO30,DSIL30,DNIT30,DPHS30,DTC30,DALK30,DCO330,DpHin30,DpCO230,mxSIL30,mnSIL30))
env.dat.reduced60<-subset(env.dat.reduced60, select=-c(SIL60, DDO60,DSIL60,DNIT60,DPHS60,DTC60,DALK60,DCO360,DpHin60,DpCO260,mxSIL60,mnSIL60))

#get equivalent variables for DVM30
lon<-ncvar_get(DVM30nc, "lon")
lat<-ncvar_get(DVM30nc, "lat")
depth<-ncvar_get(DVM30nc, "depth")
temp<-ncvar_get(DVM30nc, "temperature")
salt<-ncvar_get(DVM30nc, "salinity")
DO<-ncvar_get(DVM30nc, "oxygen")
phyt<-ncvar_get(DVM30nc, "phytoplankton")
NO3<-ncvar_get(DVM30nc, "NO3")
pH<-7.2587+0.0021314*DO+0.018633*temp
OmegaC<-1.8719*temp+0.0082364*DO+69.047/temp-0.046982*temp^2-20.343

#severity index thresholds
Tcrit<-15		#Pauley et al., 1989; Gutermuth and Armstrong, 1989; Curtis and McGaw, 2012
Scrit<-20		#Robinson and Potts, 1979 
DOcrit<-62		#From Norton et al., 2020
pHcrit<-7.75	#From Norton et al., 2020
OmegaCcrit<-1	#From Norton et al., 2020

#Figure 1: Map of stations
dev.new(width=5,height=5)
par(mar=c(2,2,1,1))
lonlim<-c(-131,-123)
latlim<-c(45,53)
mapPlot(coastlineWorldFine,projection="+proj=merc",col="lightgray",longitudelim=lonlim,latitudelim=latlim,grid=FALSE)
mapPoints(env.dat.reduced60$Long, env.dat.reduced60$Lat,pch=sym,col=pal)
mapText(env.dat.reduced60$Long-c(.5,-.2,.5,.5,-.2,.5,.5,.5,.5),env.dat.reduced60$Lat-c(0,.2,0,0,.2,0,0,0,0),labels=env.dat.reduced60$Sta,col=pal)

#Figure 3 particle trajectories for DVM30
lonlim2<-c(-128,-123)
latlim2<-c(45,50)
dev.new(width=5,height=8)
par(mfrow=c(4,2),mar=c(2,2,1,1))

for(i in 1:(length(stn)-2)) {
	lon.tmp<-env.dat.reduced30$Long[i]
	lat.tmp<-env.dat.reduced30$Lat[i]
	lon.tmpDVM<-lon[seq(1,5100,by=100)]
	lat.tmpDVM<-lat[seq(1,5100,by=100)]
	lon.diff<-lon.tmp-lon.tmpDVM
	lat.diff<-lat.tmp-lat.tmpDVM
	diff<-sqrt(lon.diff^2+lat.diff^2) 
	pick<-which(diff==min(diff))
	pick_all<-c(pick*100-99):c(pick*100)							#all the particles for the selected lat/lon. 
	
	latS<-lat[pick_all,3:721]
	lonS<-lon[pick_all,3:721]
	depthS<-depth[pick_all,3:721]*-1
	tempS<-temp[pick_all,3:721]
	saltS<-salt[pick_all,3:721]
	DOS<-DO[pick_all,3:721]
	phytS<-phyt[pick_all,3:721]
	NO3S<-NO3[pick_all,3:721]
	pHS<-pH[pick_all,3:721]
	OmegaCS<-OmegaC[pick_all,3:721]
	
	#particles that hit the model domain retain a contanst depth for the rest of the 720 hours. Replace with NA
	foo<-function(x){which(x==0)[1]}								#helper function
	bar<-depthS[,2:719]-depthS[,1:718]								#see where depth changes between timesteps
	outT<-apply(bar,1,foo)											#identify first timestep that hits domain boundary
	out<-which(outT>1)
	
	if(length(out)>0) {
	for(j in 1:length(out)) {
		latS[out[j],outT[out][j]:719]<-NA
		lonS[out[j],outT[out][j]:719]<-NA
		depthS[out[j],outT[out][j]:719]<-NA
		tempS[out[j],outT[out][j]:719]<-NA
		saltS[out[j],outT[out][j]:719]<-NA
		DOS[out[j],outT[out][j]:719]<-NA
		phytS[out[j],outT[out][j]:719]<-NA
		NO3S[out[j],outT[out][j]:719]<-NA
		pHS[out[j],outT[out][j]:719]<-NA
		OmegaCS[out[j],outT[out][j]:719]<-NA
		}
	}
	
	env.dat.DVM30[i,1]<-stn[i]								#station name
	env.dat.DVM30[i,2]<-mean(latS,na.rm=T)					#mean latitude
	env.dat.DVM30[i,3]<-mean(lonS,na.rm=T)					#mean longitude
	env.dat.DVM30[i,4]<-mean(depthS,na.rm=T)				#mean depth of 100 particles across all time steps
	env.dat.DVM30[i,5]<-mean(tempS,na.rm=T)					#mean temperature
	env.dat.DVM30[i,6]<-mean(saltS,na.rm=T)					#mean salinity
	env.dat.DVM30[i,7]<-mean(DOS,na.rm=T)					#mean dissolved oxygen
	env.dat.DVM30[i,8]<-mean(phytS,na.rm=T)					#mean phytoplankton concentration
	env.dat.DVM30[i,9]<-mean(NO3S,na.rm=T)					#mean nitrate
	env.dat.DVM30[i,10]<-mean(pHS,na.rm=T)					#mean pH
	env.dat.DVM30[i,11]<-mean(OmegaCS,na.rm=T)				#mean calcite saturation state
	
	#vertical gradients
	surf<-which(depthS<2)											#approximate surface habitat as 2m or shallower
	deep<-which(depthS>10)											#approximate deep habitat as 10m or deeper
	env.dat.DVM30[i,12]<-mean(tempS[surf])-mean(tempS[deep])		#temperature gradient
	env.dat.DVM30[i,13]<-mean(saltS[surf])-mean(saltS[deep])		#salinity gradient
	env.dat.DVM30[i,14]<-mean(OmegaCS[surf])-mean(OmegaCS[deep])	#calcite saturation state gradient
	
	#maxima
	env.dat.DVM30[i,15]<-mean(sort(tempS,decreasing = TRUE)[1:length(tempS)*0.05])		#average of highest 5% of temperatures				
	env.dat.DVM30[i,16]<-mean(sort(saltS,decreasing = TRUE)[1:length(saltS)*0.05])		#average of highest 5% of salinities
	env.dat.DVM30[i,17]<-mean(sort(DOS,decreasing = TRUE)[1:length(DOS)*0.05])			#average of highest 5% of DOs	
	env.dat.DVM30[i,18]<-mean(sort(phytS,decreasing = TRUE)[1:length(phytS)*0.05])		#average of highest 5% of phytoplankton []	
	env.dat.DVM30[i,19]<-mean(sort(NO3S,decreasing = TRUE)[1:length(NO3S)*0.05])		#average of highest 5% of nitrate	
	env.dat.DVM30[i,20]<-mean(sort(pHS,decreasing = TRUE)[1:length(pHS)*0.05])			#average of highest 5% of pH	
	env.dat.DVM30[i,21]<-mean(sort(OmegaCS,decreasing = TRUE)[1:length(OmegaCS)*0.05])	#average of highest 5% of calcite saturation state	
	
	#minima
	env.dat.DVM30[i,22]<-mean(sort(tempS)[1:length(tempS)*0.05])		#average of lowest 5% of temperatures				
	env.dat.DVM30[i,23]<-mean(sort(saltS)[1:length(saltS)*0.05])		#average of lowest 5% of salinities
	env.dat.DVM30[i,24]<-mean(sort(DOS)[1:length(DOS)*0.05])			#average of lowest 5% of DOs	
	env.dat.DVM30[i,25]<-mean(sort(phytS)[1:length(phytS)*0.05])		#average of lowest 5% of phytoplankton []	
	env.dat.DVM30[i,26]<-mean(sort(NO3S)[1:length(NO3S)*0.05])			#average of lowest 5% of nitrate	
	env.dat.DVM30[i,27]<-mean(sort(pHS)[1:length(pHS)*0.05])			#average of lowest 5% of pH	
	env.dat.DVM30[i,28]<-mean(sort(OmegaCS)[1:length(OmegaCS)*0.05])	#average of lowest 5% of calcite saturation state	
	
	#severity index calculations
	Tsubcrit<-tempS[which(tempS>Tcrit)]								#values above threshold
	env.dat.DVM30[i,29]<-sum((Tsubcrit-Tcrit)/Tcrit/24)/100			#fractional magnitude of anomaly converted to days per particle (24hrs/day, 100particles)
	Ssubcrit<-saltS[which(saltS<Scrit)]	
	env.dat.DVM30[i,30]<-sum((Scrit-Ssubcrit)/Scrit/24)/100						
	DOsubcrit<-DOS[which(DOS<DOcrit)]	
	env.dat.DVM30[i,31]<-sum((DOcrit-DOsubcrit)/DOcrit/24)/100
	pHsubcrit<-pHS[which(pHS<pHcrit)]	
	env.dat.DVM30[i,32]<-sum((pHcrit-pHsubcrit)/pHcrit/24)/100	
	OmegaCsubcrit<-OmegaCS[which(OmegaCS<OmegaCcrit)]	
	env.dat.DVM30[i,33]<-sum((OmegaCcrit-OmegaCsubcrit)/OmegaCcrit/24)/100	
							
	#repeat for time of molt scenario. Consider particles that hit the domain edge to be at point of molt
	latSmolt<-latS[,695:719]
	lonSmolt<-lonS[,695:719]
	depthSmolt<-depthS[,695:719]
	tempSmolt<-tempS[,695:719]
	saltSmolt<-saltS[,695:719]
	DOSmolt<-DOS[,695:719]
	phytSmolt<-phytS[,695:719]
	NO3Smolt<-NO3S[,695:719]
	pHSmolt<-pHS[,695:719]
	OmegaCSmolt<-OmegaCS[,695:719]
	
	if(length(out)>0) {
	for (j in 1:length(out)){
		latSmolt[out[j],]<-latS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		lonSmolt[out[j],]<-lonS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		depthSmolt[out[j],]<-depthS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		tempSmolt[out[j],]<-tempS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		saltSmolt[out[j],]<-saltS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		DOSmolt[out[j],]<-DOS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		phytSmolt[out[j],]<-phytS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		NO3Smolt[out[j],]<-NO3S[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		pHSmolt[out[j],]<-pHS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		OmegaCSmolt[out[j],]<-OmegaCS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		}
	}
	
	env.dat.moltDVM30[i,1]<-stn[i]							#station name
	env.dat.moltDVM30[i,2]<-mean(latSmolt)					#closest latitude
	env.dat.moltDVM30[i,3]<-mean(lonSmolt)					#closest longitude
	env.dat.moltDVM30[i,4]<-mean(depthSmolt)				#mean depth of 100 particles across all first 24 hours after molt
	env.dat.moltDVM30[i,5]<-mean(tempSmolt)					#mean temperature
	env.dat.moltDVM30[i,6]<-mean(saltSmolt)					#mean salinity
	env.dat.moltDVM30[i,7]<-mean(DOSmolt)					#mean dissolved oxygen
	env.dat.moltDVM30[i,8]<-mean(phytSmolt)					#mean phytoplankton concentration
	env.dat.moltDVM30[i,9]<-mean(NO3Smolt)					#mean nitrate
	env.dat.moltDVM30[i,10]<-mean(pHSmolt)					#mean pH
	env.dat.moltDVM30[i,11]<-mean(OmegaCSmolt)				#mean calcite saturation state
	
	#maxima
	env.dat.moltDVM30[i,12]<-mean(sort(tempSmolt,decreasing = TRUE)[1:length(tempSmolt)*0.05])		#average of highest 5% of temperatures				
	env.dat.moltDVM30[i,13]<-mean(sort(saltSmolt,decreasing = TRUE)[1:length(saltSmolt)*0.05])		#average of highest 5% of salinities
	env.dat.moltDVM30[i,14]<-mean(sort(DOSmolt,decreasing = TRUE)[1:length(DOSmolt)*0.05])			#average of highest 5% of DOs	
	env.dat.moltDVM30[i,15]<-mean(sort(phytSmolt,decreasing = TRUE)[1:length(phytSmolt)*0.05])		#average of highest 5% of phytoplankton []	
	env.dat.moltDVM30[i,16]<-mean(sort(NO3Smolt,decreasing = TRUE)[1:length(NO3Smolt)*0.05])		#average of highest 5% of nitrate	
	env.dat.moltDVM30[i,17]<-mean(sort(pHSmolt,decreasing = TRUE)[1:length(pHSmolt)*0.05])			#average of highest 5% of pH	
	env.dat.moltDVM30[i,18]<-mean(sort(OmegaCSmolt,decreasing = TRUE)[1:length(OmegaCSmolt)*0.05])	#average of highest 5% of calcite saturation state	
	
	#minima
	env.dat.moltDVM30[i,19]<-mean(sort(tempSmolt)[1:length(tempSmolt)*0.05])		#average of lowest 5% of temperatures				
	env.dat.moltDVM30[i,20]<-mean(sort(saltSmolt)[1:length(saltSmolt)*0.05])		#average of lowest 5% of salinities
	env.dat.moltDVM30[i,21]<-mean(sort(DOSmolt)[1:length(DOSmolt)*0.05])			#average of lowest 5% of DOs	
	env.dat.moltDVM30[i,22]<-mean(sort(phytSmolt)[1:length(phytSmolt)*0.05])		#average of lowest 5% of phytoplankton []	
	env.dat.moltDVM30[i,23]<-mean(sort(NO3Smolt)[1:length(NO3Smolt)*0.05])			#average of lowest 5% of nitrate	
	env.dat.moltDVM30[i,24]<-mean(sort(pHSmolt)[1:length(pHSmolt)*0.05])			#average of lowest 5% of pH	
	env.dat.moltDVM30[i,25]<-mean(sort(OmegaCSmolt)[1:length(OmegaCSmolt)*0.05])	#average of lowest 5% of calcite saturation state	
	
	#add trajectories to map
	mapPlot(coastlineWorldFine,projection="+proj=merc",col="lightgray",longitudelim=lonlim2,latitudelim=latlim2,grid=FALSE,axes=FALSE)
	mapPoints(lonS,latS,col=pal[i],cex=0.2)
	mapPoints(lonSmolt,latSmolt,pch=20,col="red",cex=0.2)
	mapPoints(lon.tmp,lat.tmp)
	mapText(lon.tmp-0.7,lat.tmp,labels=stn[i],col=pal[i])
}

#example of DVM30
matplot(t(depthS),type="l",col=rgb(0,0,0,alpha = 0.1),ylim=c(120,2),main="DVM30 example, station 120",las=1,xlab="hours prior to collection", ylab = "depth (m)")

names(env.dat.DVM30)<-c("Sta","Lat","Long","Depth","TDVM30","SDVM30","DODVM30","phytDVM30","NITDVM30","pHDVM30","OmegaCDVM30","DTDVM30","DSDVM30","DOmegaCDVM30","mxTDVM30","mxSDVM30","mxDODVM30","mxphytDVM30","mxNITDVM30","mxpHDVM30","mxOmegaCDVM30","mnTDVM30","mnSDVM30","mnDODVM30","mnphytDVM30","mnNITDVM30","mnpHDVM30","mnOmegaCDVM30","TSIDVM30","SSIDVM30","DOSIDVM30","pHSIDVM30","OmegaCSIDVM30")
names(env.dat.moltDVM30)<-c("Sta","Lat","Long","Depth","TmoltDVM30","SmoltDVM30","DOmoltDVM30","phytmoltDVM30","NITmoltDVM30","pHmoltDVM30","OmegaCmoltDVM30","mxTmoltDVM30","mxSmoltDVM30","mxDOmoltDVM30","mxphytmoltDVM30","mxNITmoltDVM30","mxpHmoltDVM30","mxOmegaCmoltDVM30","mnTmoltDVM30","mnSmoltDVM30","mnDOmoltDVM30","mnphytmoltDVM30","mnNITmoltDVM30","mnpHmoltDVM30","mnOmegaCmoltDVM30")

#repeat for DVM60
lon<-ncvar_get(DVM60nc, "lon")
lat<-ncvar_get(DVM60nc, "lat")
depth<-ncvar_get(DVM60nc, "depth")
temp<-ncvar_get(DVM60nc, "temperature")
salt<-ncvar_get(DVM60nc, "salinity")
DO<-ncvar_get(DVM60nc, "oxygen")
phyt<-ncvar_get(DVM60nc, "phytoplankton")
NO3<-ncvar_get(DVM60nc, "NO3")
pH<-7.2587+0.0021314*DO+0.018633*temp
OmegaC<-1.8719*temp+0.0082364*DO+69.047/temp-0.046982*temp^2-20.343
OmegaC[is.infinite(OmegaC)]<-NA

#Figure 4: particle trajectories for DVM60
dev.new(width=5,height=8)
par(mfrow=c(4,2),mar=c(2,2,1,1))

for(i in 1:(length(stn)-2)) {
	lon.tmp<-env.dat.reduced60$Long[i]
	lat.tmp<-env.dat.reduced60$Lat[i]
	lon.tmpDVM<-lon[seq(1,5100,by=100)]
	lat.tmpDVM<-lat[seq(1,5100,by=100)]
	lon.diff<-lon.tmp-lon.tmpDVM
	lat.diff<-lat.tmp-lat.tmpDVM
	diff<-sqrt(lon.diff^2+lat.diff^2) 
	pick<-which(diff==min(diff))
	pick_all<-c(pick*100-99):c(pick*100)							#all the particles for the selected lat/lon. 
	
	latS<-lat[pick_all,3:721]
	lonS<-lon[pick_all,3:721]
	depthS<-depth[pick_all,3:721]*-1
	tempS<-temp[pick_all,3:721]
	saltS<-salt[pick_all,3:721]
	DOS<-DO[pick_all,3:721]
	phytS<-phyt[pick_all,3:721]
	NO3S<-NO3[pick_all,3:721]
	pHS<-pH[pick_all,3:721]
	OmegaCS<-OmegaC[pick_all,3:721]
	
	#particles that hit the model domain retain a contanst depth for the rest of the 720 hours. Replace with NA
	foo<-function(x){which(x==0)[1]}								#helper function
	bar<-depthS[,2:719]-depthS[,1:718]								#see where depth changes between timesteps
	outT<-apply(bar,1,foo)											#identify first timestep that hits domain boundary
	out<-which(outT>1)
	
	if(length(out)>0) {
	for(j in 1:length(out)) {
		latS[out[j],outT[out][j]:719]<-NA
		lonS[out[j],outT[out][j]:719]<-NA
		depthS[out[j],outT[out][j]:719]<-NA
		tempS[out[j],outT[out][j]:719]<-NA
		saltS[out[j],outT[out][j]:719]<-NA
		DOS[out[j],outT[out][j]:719]<-NA
		phytS[out[j],outT[out][j]:719]<-NA
		NO3S[out[j],outT[out][j]:719]<-NA
		pHS[out[j],outT[out][j]:719]<-NA
		OmegaCS[out[j],outT[out][j]:719]<-NA
		}
	}
	
	env.dat.DVM60[i,1]<-stn[i]								#station name
	env.dat.DVM60[i,2]<-mean(latS,na.rm=T)					#mean latitude
	env.dat.DVM60[i,3]<-mean(lonS,na.rm=T)					#mean longitude
	env.dat.DVM60[i,4]<-mean(depthS,na.rm=T)				#mean depth of 100 particles across all time steps
	env.dat.DVM60[i,5]<-mean(tempS,na.rm=T)					#mean temperature
	env.dat.DVM60[i,6]<-mean(saltS,na.rm=T)					#mean salinity
	env.dat.DVM60[i,7]<-mean(DOS,na.rm=T)					#mean dissolved oxygen
	env.dat.DVM60[i,8]<-mean(phytS,na.rm=T)					#mean phytoplankton concentration
	env.dat.DVM60[i,9]<-mean(NO3S,na.rm=T)					#mean nitrate
	env.dat.DVM60[i,10]<-mean(pHS,na.rm=T)					#mean pH
	env.dat.DVM60[i,11]<-mean(OmegaCS,na.rm=T)				#mean calcite saturation state
	
	#vertical gradients
	surf<-which(depthS<2)											#approximate surface habitat as 2m or shallower
	deep<-which(depthS>10)											#approximate deep habitat as 10m or deeper
	env.dat.DVM60[i,12]<-mean(tempS[surf])-mean(tempS[deep])		#mean temperature
	env.dat.DVM60[i,13]<-mean(saltS[surf])-mean(saltS[deep])		#mean salinity
	env.dat.DVM60[i,14]<-mean(DOS[surf])-mean(DOS[deep])			#mean dissolved oxygen
	env.dat.DVM60[i,15]<-mean(phytS[surf])-mean(phytS[deep])		#mean phytoplankton concentration
	env.dat.DVM60[i,16]<-mean(NO3S[surf])-mean(NO3S[deep])			#mean nitrate
	env.dat.DVM60[i,17]<-mean(pHS[surf])-mean(pHS[deep])			#mean pH
	env.dat.DVM60[i,18]<-mean(OmegaCS[surf])-mean(OmegaCS[deep])	#mean calcite saturation state					
	
	#maxima
	env.dat.DVM60[i,15]<-mean(sort(tempS,decreasing = TRUE)[1:length(tempS)*0.05])		#average of highest 5% of temperatures				
	env.dat.DVM60[i,16]<-mean(sort(saltS,decreasing = TRUE)[1:length(saltS)*0.05])		#average of highest 5% of salinities
	env.dat.DVM60[i,17]<-mean(sort(DOS,decreasing = TRUE)[1:length(DOS)*0.05])			#average of highest 5% of DOs	
	env.dat.DVM60[i,18]<-mean(sort(phytS,decreasing = TRUE)[1:length(phytS)*0.05])		#average of highest 5% of phytoplankton []	
	env.dat.DVM60[i,19]<-mean(sort(NO3S,decreasing = TRUE)[1:length(NO3S)*0.05])		#average of highest 5% of nitrate	
	env.dat.DVM60[i,20]<-mean(sort(pHS,decreasing = TRUE)[1:length(pHS)*0.05])			#average of highest 5% of pH	
	env.dat.DVM60[i,21]<-mean(sort(OmegaCS,decreasing = TRUE)[1:length(OmegaCS)*0.05])	#average of highest 5% of calcite saturation state	
	
	#minima
	env.dat.DVM60[i,22]<-mean(sort(tempS)[1:length(tempS)*0.05])		#average of lowest 5% of temperatures				
	env.dat.DVM60[i,23]<-mean(sort(saltS)[1:length(saltS)*0.05])		#average of lowest 5% of salinities
	env.dat.DVM60[i,24]<-mean(sort(DOS)[1:length(DOS)*0.05])			#average of lowest 5% of DOs	
	env.dat.DVM60[i,25]<-mean(sort(phytS)[1:length(phytS)*0.05])		#average of lowest 5% of phytoplankton []	
	env.dat.DVM60[i,26]<-mean(sort(NO3S)[1:length(NO3S)*0.05])			#average of lowest 5% of nitrate	
	env.dat.DVM60[i,27]<-mean(sort(pHS)[1:length(pHS)*0.05])			#average of lowest 5% of pH	
	env.dat.DVM60[i,28]<-mean(sort(OmegaCS)[1:length(OmegaCS)*0.05])	#average of lowest 5% of calcite saturation state	
	
	#severity index calculations
	Tsubcrit<-tempS[which(tempS>Tcrit)]								#values above threshold
	env.dat.DVM60[i,29]<-sum((Tsubcrit-Tcrit)/Tcrit/24)/100			#fractional magnitude of anomaly converted to days per particle (24hrs/day, 100particles)
	Ssubcrit<-saltS[which(saltS<Scrit)]	
	env.dat.DVM60[i,30]<-sum((Scrit-Ssubcrit)/Scrit/24)/100						
	DOsubcrit<-DOS[which(DOS<DOcrit)]	
	env.dat.DVM60[i,31]<-sum((DOcrit-DOsubcrit)/DOcrit/24)/100
	pHsubcrit<-pHS[which(pHS<pHcrit)]	
	env.dat.DVM60[i,32]<-sum((pHcrit-pHsubcrit)/pHcrit/24)/100	
	OmegaCsubcrit<-OmegaCS[which(OmegaCS<OmegaCcrit)]	
	env.dat.DVM60[i,33]<-sum((OmegaCcrit-OmegaCsubcrit)/OmegaCcrit/24)/100	
							
	#repeat for time of molt scenario. Consider particles that hit the domain edge to be at point of molt
	latSmolt<-latS[,695:719]
	lonSmolt<-lonS[,695:719]
	depthSmolt<-depthS[,695:719]
	tempSmolt<-tempS[,695:719]
	saltSmolt<-saltS[,695:719]
	DOSmolt<-DOS[,695:719]
	phytSmolt<-phytS[,695:719]
	NO3Smolt<-NO3S[,695:719]
	pHSmolt<-pHS[,695:719]
	OmegaCSmolt<-OmegaCS[,695:719]
	
	if(length(out)>0) {
	for (j in 1:length(out)){
		latSmolt[out[j],]<-latS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		lonSmolt[out[j],]<-lonS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		depthSmolt[out[j],]<-depthS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		tempSmolt[out[j],]<-tempS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		saltSmolt[out[j],]<-saltS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		DOSmolt[out[j],]<-DOS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		phytSmolt[out[j],]<-phytS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		NO3Smolt[out[j],]<-NO3S[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		pHSmolt[out[j],]<-pHS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		OmegaCSmolt[out[j],]<-OmegaCS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		}
	}
	
	env.dat.moltDVM60[i,1]<-stn[i]							#station name
	env.dat.moltDVM60[i,2]<-mean(latSmolt)					#closest latitude
	env.dat.moltDVM60[i,3]<-mean(lonSmolt)					#closest longitude
	env.dat.moltDVM60[i,4]<-mean(depthSmolt)				#mean depth of 100 particles across all first 24 hours after molt
	env.dat.moltDVM60[i,5]<-mean(tempSmolt)					#mean temperature
	env.dat.moltDVM60[i,6]<-mean(saltSmolt)					#mean salinity
	env.dat.moltDVM60[i,7]<-mean(DOSmolt)					#mean dissolved oxygen
	env.dat.moltDVM60[i,8]<-mean(phytSmolt)					#mean phytoplankton concentration
	env.dat.moltDVM60[i,9]<-mean(NO3Smolt)					#mean nitrate
	env.dat.moltDVM60[i,10]<-mean(pHSmolt)					#mean pH
	env.dat.moltDVM60[i,11]<-mean(OmegaCSmolt)				#mean calcite saturation state
	
	#maxima
	env.dat.moltDVM60[i,12]<-mean(sort(tempSmolt,decreasing = TRUE)[1:length(tempSmolt)*0.05])		#average of highest 5% of temperatures				
	env.dat.moltDVM60[i,13]<-mean(sort(saltSmolt,decreasing = TRUE)[1:length(saltSmolt)*0.05])		#average of highest 5% of salinities
	env.dat.moltDVM60[i,14]<-mean(sort(DOSmolt,decreasing = TRUE)[1:length(DOSmolt)*0.05])			#average of highest 5% of DOs	
	env.dat.moltDVM60[i,15]<-mean(sort(phytSmolt,decreasing = TRUE)[1:length(phytSmolt)*0.05])		#average of highest 5% of phytoplankton []	
	env.dat.moltDVM60[i,16]<-mean(sort(NO3Smolt,decreasing = TRUE)[1:length(NO3Smolt)*0.05])		#average of highest 5% of nitrate	
	env.dat.moltDVM60[i,17]<-mean(sort(pHSmolt,decreasing = TRUE)[1:length(pHSmolt)*0.05])			#average of highest 5% of pH	
	env.dat.moltDVM60[i,18]<-mean(sort(OmegaCSmolt,decreasing = TRUE)[1:length(OmegaCSmolt)*0.05])	#average of highest 5% of calcite saturation state	
	
	#minima
	env.dat.moltDVM60[i,19]<-mean(sort(tempSmolt)[1:length(tempSmolt)*0.05])		#average of lowest 5% of temperatures				
	env.dat.moltDVM60[i,20]<-mean(sort(saltSmolt)[1:length(saltSmolt)*0.05])		#average of lowest 5% of salinities
	env.dat.moltDVM60[i,21]<-mean(sort(DOSmolt)[1:length(DOSmolt)*0.05])			#average of lowest 5% of DOs	
	env.dat.moltDVM60[i,22]<-mean(sort(phytSmolt)[1:length(phytSmolt)*0.05])		#average of lowest 5% of phytoplankton []	
	env.dat.moltDVM60[i,23]<-mean(sort(NO3Smolt)[1:length(NO3Smolt)*0.05])			#average of lowest 5% of nitrate	
	env.dat.moltDVM60[i,24]<-mean(sort(pHSmolt)[1:length(pHSmolt)*0.05])			#average of lowest 5% of pH	
	env.dat.moltDVM60[i,25]<-mean(sort(OmegaCSmolt)[1:length(OmegaCSmolt)*0.05])	#average of lowest 5% of calcite saturation state	
	
	#add trajectories to map
	mapPlot(coastlineWorldFine,projection="+proj=merc",col="lightgray",longitudelim=lonlim2,latitudelim=latlim2,grid=FALSE,axes=FALSE)
	mapPoints(lonS,latS,col=pal[i],cex=0.2)
	mapPoints(lonSmolt,latSmolt,pch=20,col="red",cex=0.2)
	mapPoints(lon.tmp,lat.tmp)
	mapText(lon.tmp-0.7,lat.tmp,labels=stn[i],col=pal[i])
}

#example of DVM60
matplot(t(depthS),type="l",col=rgb(0,0,0,alpha = 0.1),ylim=c(120,2),main="DVM60 example, station 120",las=1,xlab="hours prior to collection", ylab = "depth (m)")

names(env.dat.DVM60)<-c("Sta","Lat","Long","Depth","TDVM60","SDVM60","DODVM60","phytDVM60","NITDVM60","pHDVM60","OmegaCDVM60","DTDVM60","DSDVM60","DOmegaCDVM60","mxTDVM60","mxSDVM60","mxDODVM60","mxphytDVM60","mxNITDVM60","mxpHDVM60","mxOmegaCDVM60","mnTDVM60","mnSDVM60","mnDODVM60","mnphytDVM60","mnNITDVM60","mnpHDVM60","mnOmegaCDVM60","TSIDVM60","SSIDVM60","DOSIDVM60","pHSIDVM60","OmegaCSIDVM60")
names(env.dat.moltDVM60)<-c("Sta","Lat","Long","Depth","TmoltDVM60","SmoltDVM60","DOmoltDVM60","phytmoltDVM60","NITmoltDVM60","pHmoltDVM60","OmegaCmoltDVM60","mxTmoltDVM60","mxSmoltDVM60","mxDOmoltDVM60","mxphytmoltDVM60","mxNITmoltDVM60","mxpHmoltDVM60","mxOmegaCmoltDVM60","mnTmoltDVM60","mnSmoltDVM60","mnDOmoltDVM60","mnphytmoltDVM60","mnNITmoltDVM60","mnpHmoltDVM60","mnOmegaCmoltDVM60")

######Evaluate best predictors######
#Best model for each behavior. Forward selection, AICc as the selector
env.dat.reduced30$GS = GS 
dat = env.dat.reduced30[5:ncol(env.dat.reduced30)]
int30<-data.frame(matrix(,ncol=5,nrow=ncol(dat)-1))
colnames(int30)<-c('Variable','AICc','DAICc','likelihood','xbetter')
for (i in 1:(ncol(dat)-1)) {
	fit<-lm(dat$GS~dat[,i])
	int30[i,1]<-colnames(dat)[i]
	int30[i,2]<-AICc(fit)
}
int30[,3]<-int30$AICc-min(int30$AICc)
int30[,4]<-exp(-0.5*int30$DAICc)
int30[,5]<-1/int30$likelihood
int30[order(int30$AICc),]

env.dat.reduced60$GS = GS
dat = env.dat.reduced60[5:ncol(env.dat.reduced60)]
int60<-data.frame(matrix(,ncol=5,nrow=ncol(dat)-1))
colnames(int60)<-c('Variable','AICc','DAICc','likelihood','xbetter')
for (i in 1:(ncol(dat)-1)) {
	fit<-lm(dat$GS~dat[,i])
	int60[i,1]<-colnames(dat)[i]
	int60[i,2]<-AICc(fit)
}
int60[,3]<-int60$AICc-min(int60$AICc)
int60[,4]<-exp(-0.5*int60$DAICc)
int60[,5]<-1/int60$likelihood
int60[order(int60$AICc),]

env.dat.DVM30$GS = GS[1:7]
dat = env.dat.DVM30[5:ncol(env.dat.DVM30)]
DVM30<-data.frame(matrix(,ncol=5,nrow=ncol(dat)-1))
colnames(DVM30)<-c('Variable','AICc','DAICc','likelihood','xbetter')
for (i in 1:(ncol(dat)-1)) {
	fit<-lm(dat$GS~dat[,i])
	DVM30[i,1]<-colnames(dat)[i]
	DVM30[i,2]<-AICc(fit)
}
DVM30[,3]<-DVM30$AICc-min(DVM30$AICc)
DVM30[,4]<-exp(-0.5*DVM30$DAICc)
DVM30[,5]<-1/DVM30$likelihood
DVM30[order(DVM30$AICc),]

env.dat.DVM60$GS = GS[1:7]
dat = env.dat.DVM60[5:ncol(env.dat.DVM60)]
DVM60<-data.frame(matrix(,ncol=5,nrow=ncol(dat)-1))
colnames(DVM60)<-c('Variable','AICc','DAICc','likelihood','xbetter')
for (i in 1:(ncol(dat)-1)) {
	fit<-lm(dat$GS~dat[,i])
	DVM60[i,1]<-colnames(dat)[i]
	DVM60[i,2]<-AICc(fit)
}
DVM60[,3]<-DVM60$AICc-min(DVM60$AICc)
DVM60[,4]<-exp(-0.5*DVM60$DAICc)
DVM60[,5]<-1/DVM60$likelihood
DVM60[order(DVM60$AICc),]

env.dat.moltDVM30$GS = GS[1:7]
dat = env.dat.moltDVM30[5:ncol(env.dat.moltDVM30)]
moltDVM30<-data.frame(matrix(,ncol=5,nrow=ncol(dat)-1))
colnames(moltDVM30)<-c('Variable','AICc','DAICc','likelihood','xbetter')
for (i in 1:(ncol(dat)-1)) {
	fit<-lm(dat$GS~dat[,i])
	moltDVM30[i,1]<-colnames(dat)[i]
	moltDVM30[i,2]<-AICc(fit)
}
moltDVM30[,3]<-moltDVM30$AICc-min(moltDVM30$AICc)
moltDVM30[,4]<-exp(-0.5*moltDVM30$DAICc)
moltDVM30[,5]<-1/moltDVM30$likelihood
moltDVM30[order(moltDVM30$AICc),]

env.dat.moltDVM60$GS = GS[1:7]
dat = env.dat.moltDVM60[5:ncol(env.dat.moltDVM60)]
moltDVM60<-data.frame(matrix(,ncol=5,nrow=ncol(dat)-1))
colnames(moltDVM60)<-c('Variable','AICc','DAICc','likelihood','xbetter')
for (i in 1:(ncol(dat)-1)) {
	fit<-lm(dat$GS~dat[,i])
	moltDVM60[i,1]<-colnames(dat)[i]
	moltDVM60[i,2]<-AICc(fit)
}
moltDVM60[,3]<-moltDVM60$AICc-min(moltDVM60$AICc)
moltDVM60[,4]<-exp(-0.5*moltDVM60$DAICc)
moltDVM60[,5]<-1/moltDVM60$likelihood
moltDVM60[order(moltDVM60$AICc),]

#everything at 30m
dat<-cbind(env.dat.reduced30[1:7,5:ncol(env.dat.reduced30)],env.dat.DVM30[5:ncol(env.dat.DVM30)],env.dat.moltDVM30[5:ncol(env.dat.moltDVM30)])
dat<-dat[-c(38,68)]
all30<-data.frame(matrix(,ncol=5,nrow=ncol(dat)-1))
colnames(all30)<-c('Variable','AICc','DAICc','likelihood','xbetter')
for (i in 1:(ncol(dat)-1)) {
	fit<-lm(dat$GS~dat[,i])
	all30[i,1]<-colnames(dat)[i]
	all30[i,2]<-AICc(fit)
}
all30[,3]<-all30$AICc-min(all30$AICc)
all30[,4]<-exp(-0.5*all30$DAICc)
all30[,5]<-1/all30$likelihood
all30[order(all30$AICc),]

#retain mnpHmoltDVM30
all30_2<-data.frame(matrix(,ncol=5,nrow=ncol(dat)-1))
colnames(all30_2)<-c('Variable','AICc','DAICc','likelihood','xbetter')
for (i in 1:(ncol(dat)-1)) {
	fit<-lm(dat$GS~dat$mnpHmoltDVM30+dat[,i])
	all30_2[i,1]<-colnames(dat)[i]
	all30_2[i,2]<-AICc(fit)
}
all30_2[,3]<-all30_2$AICc-min(all30_2$AICc)
all30_2[,4]<-exp(-0.5*all30_2$DAICc)
all30_2[,5]<-1/all30_2$likelihood
all30_2[order(all30_2$AICc),]

#everything at 60m
dat<-cbind(env.dat.reduced60[1:7,5:ncol(env.dat.reduced60)],env.dat.DVM60[5:ncol(env.dat.DVM60)],env.dat.moltDVM60[5:ncol(env.dat.moltDVM60)])
dat<-dat[-c(38,68)]
all60<-data.frame(matrix(,ncol=5,nrow=ncol(dat)-1))
colnames(all60)<-c('Variable','AICc','DAICc','likelihood','xbetter')
for (i in 1:(ncol(dat)-1)) {
	fit<-lm(dat$GS~dat[,i])
	all60[i,1]<-colnames(dat)[i]
	all60[i,2]<-AICc(fit)
}
all60[,3]<-all60$AICc-min(all60$AICc)
all60[,4]<-exp(-0.5*all60$DAICc)
all60[,5]<-1/all60$likelihood
all60[order(all60$AICc),]

#retain TmoltDVM60
all60_2<-data.frame(matrix(,ncol=5,nrow=ncol(dat)-1))
colnames(all60_2)<-c('Variable','AICc','DAICc','likelihood','xbetter')
for (i in 1:(ncol(dat)-1)) {
	fit<-lm(dat$GS~dat$TmoltDVM60+dat[,i])
	all60_2[i,1]<-colnames(dat)[i]
	all60_2[i,2]<-AICc(fit)
}
all60_2[,3]<-all60_2$AICc-min(all60_2$AICc)
all60_2[,4]<-exp(-0.5*all60_2$DAICc)
all60_2[,5]<-1/all60_2$likelihood
all60_2[order(all60_2$AICc),]

#results above suggest the following:
#int30 (9 sites): mxDO30 (AICc = 26.70031)
#int60 (9 sites): mxDO60, note that this is the same as above (AICc = 26.70031)
#DVM30: mnTDVM30 (AICc = 27.90268)
#DVM60: DOmegaCDVM60 (AICc = 23.33362)
#moltDVM30: mnpHmoltDVM30 (AICc = 19.97635)
#moltDVM60: TmoltDVM60 (AICc = 20.69628) 
#all30: mnpHmoltDVM30 (AICc = 19.97635)
#all60: TmoltDVM60 (AICc = 20.69628)

#some fits

fit1<-lm(GS[1:7]~env.dat.moltDVM30$mnpHmoltDVM30) 
fit2<-lm(GS[1:7]~env.dat.moltDVM30$mnTmoltDVM30) 
fit3<-lm(GS[1:7]~env.dat.moltDVM60$TmoltDVM60) 

#Bednarsek 2020 semi-quant dissolution values for stations 90, 94, 99, 100, 106, 114, 115, 128, 130
dis<-c(0.75, 0.41665, 0.916665, 0.604165, 0.5, 0.41665, 0.833333334, 0.458333, 0.29165)
#Bednarsek 2020 semi-quant dissolution values for stations 94, 99, 100, 106, 114, 115, 130
dis_ovlp<-dis[c(-1,-8)]
#GS for stations 94, 99, 100, 106, 114, 115, 130
GS_ovlp<-GS[c(-7,-8)]
fit4<-lm(GS_ovlp~dis_ovlp)

#Figure 5. Some best univariate models 
dev.new(width=8,height=3)
par(mfrow=c(1,3))

plot(env.dat.moltDVM30$mnpHmoltDVM30,GS[1:7],col=pal[1:7],pch=sym[1:7],las=1,xlab="minimum pH-molt",ylab="greyscale")
lines(env.dat.moltDVM30$mnpHmoltDVM30,predict(fit1))
text(env.dat.moltDVM30$mnpHmoltDVM30[1:7],GS[1:7],env.dat.reduced30$Sta[1:7],col=pal[1:7],cex=0.7,pos=c(2,1,1,3,1,1,3))
label<-bquote(italic(r)^2 == .(format(summary(fit1)$r.squared,digits = 2)))
text(max(env.dat.moltDVM30$mnpHmoltDVM30[1:7])-0.01,min(GS[1:7])+0.2,label)
text(max(env.dat.moltDVM30$mnpHmoltDVM30[1:7])-0.015,min(GS[1:7]),"AICc = 19.98")

plot(env.dat.moltDVM30$mnTmoltDVM30,GS[1:7],col=pal[1:7],pch=sym[1:7],las=1,xlab="minimum T-molt (ºC)",ylab="greyscale")
lines(env.dat.moltDVM30$mnTmoltDVM30,predict(fit2))
text(env.dat.moltDVM30$mnTmoltDVM30[1:7],GS[1:7],env.dat.reduced30$Sta[1:7],col=pal[1:7],cex=0.7,pos=c(2,1,1,3,1,1,3))
label<-bquote(italic(r)^2 == .(format(summary(fit2)$r.squared,digits = 2)))
text(max(env.dat.moltDVM30$mnTmoltDVM30[1:7])-.2,min(GS[1:7])+0.2,label)
text(max(env.dat.moltDVM30$mnTmoltDVM30[1:7])-0.3,min(GS[1:7]),"AICc = 20.04")

plot(env.dat.moltDVM60$TmoltDVM60,GS[1:7],col=pal[1:7],pch=sym[1:7],las=1,xlab="T-molt (ºC)",ylab="greyscale")
lines(env.dat.moltDVM60$TmoltDVM60,predict(fit3))
text(env.dat.moltDVM60$TmoltDVM60[1:7],GS[1:7],env.dat.reduced30$Sta[1:7],col=pal[1:7],cex=0.7,pos=c(2,1,1,3,1,1,3))
label<-bquote(italic(r)^2 == .(format(summary(fit3)$r.squared,digits = 2)))
text(max(env.dat.moltDVM60$TmoltDVM60[1:7])-.12,min(GS[1:7])+0.2,label)
text(max(env.dat.moltDVM60$TmoltDVM60[1:7])-.18,min(GS[1:7]),"AICc = 20.70")

#lat/lon bounds of JSCOPE
lonmax<-max(lon)
lonmin<-min(lon)
latmax<-max(lat)
latmin<-min(lat)

#get environmental data within the JSCOPE domain
env.dat.JS<-env.dat[which(env.dat$Lat<=latmax & env.dat$Lat>=latmin),]
env.dat.JS<-env.dat.JS[which(env.dat.JS$Lon<=lonmax & env.dat.JS$Lon>=lonmin),]

#Remove data below 65 m
env.dat.JS<-env.dat.JS[-which(env.dat.JS$Depth > 65),]
stn.JS<-unique(env.dat.JS$Sta)
lat.JS<-rep(0,length(stn.JS))
lon.JS<-rep(0,length(stn.JS))
mnpHmolt.JS<-rep(0,length(stn.JS))

#Calculate mnpHmoltDVM30
lon<-ncvar_get(DVM30nc, "lon")
lat<-ncvar_get(DVM30nc, "lat")
depth<-ncvar_get(DVM30nc, "depth")
temp<-ncvar_get(DVM30nc, "temperature")
#salt<-ncvar_get(DVM30nc, "salinity")
DO<-ncvar_get(DVM30nc, "oxygen")
#phyt<-ncvar_get(DVM30nc, "phytoplankton")
#NO3<-ncvar_get(DVM30nc, "NO3")
pH<-7.2587+0.0021314*DO+0.018633*temp
#OmegaC<-1.8719*temp+0.0082364*DO+69.047/temp-0.046982*temp^2-20.343

for(i in 1:length(stn.JS)) {
	tmp<-env.dat.JS[which(env.dat.JS$Sta==stn.JS[i]),]
	tmp<-tmp[-which(is.na(tmp$SILCAT)==T),]
	
	lon.tmp<-tmp$Long[1]
	lat.tmp<-tmp$Lat[1]
	lon.JS[i]<-lon.tmp
	lat.JS[i]<-lat.tmp
	lon.tmpDVM<-lon[seq(1,5100,by=100)]
	lat.tmpDVM<-lat[seq(1,5100,by=100)]
	lon.diff<-lon.tmp-lon.tmpDVM
	lat.diff<-lat.tmp-lat.tmpDVM
	diff<-sqrt(lon.diff^2+lat.diff^2) 
	pick<-which(diff==min(diff))
	pick_all<-c(pick*100-99):c(pick*100)							#all the particles for the selected lat/lon. 
	
	latS<-lat[pick_all,3:721]
	lonS<-lon[pick_all,3:721]
	depthS<-depth[pick_all,3:721]*-1
	pHS<-pH[pick_all,3:721]

	#particles that hit the model domain retain a contanst depth for the rest of the 720 hours. Replace with NA
	foo<-function(x){which(x==0)[1]}								#helper function
	bar<-depthS[,2:719]-depthS[,1:718]								#see where depth changes between timesteps
	outT<-apply(bar,1,foo)											#identify first timestep that hits domain boundary
	out<-which(outT>1)

	latSmolt<-latS[,695:719]
	lonSmolt<-lonS[,695:719]
	depthSmolt<-depthS[,695:719]
	pHSmolt<-pHS[,695:719]
	
	if(length(out)>0) {
	for (j in 1:length(out)){
		latSmolt[out[j],]<-latS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		lonSmolt[out[j],]<-lonS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		depthSmolt[out[j],]<-depthS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		pHSmolt[out[j],]<-pHS[out[j],(outT[out][j]-25):(outT[out][j]-1)]
		}
	}
	
	mnpHmolt.JS[i]<-mean(sort(pHSmolt)[1:length(pHSmolt)*0.05]) 			#average of lowest 5% of pH						
}

fit1.JS<-mnpHmolt.JS*fit1$coefficients[2]+fit1$coefficients[1]
leg1<-seq(7.4,7.9,.1)
leg2<-seq(13,21,2)

dev.new(width=4,height=8)

#Calculate pH at molt for all WCOA sites witin JSCOPE domain, GS and comapre to observed presence/absence
obs.dat<-read.csv("/Volumes/GoogleDrive/My Drive/WWU_GD/R_documents/megalope/Megalope_occ_obs.csv",header=T)

pres<-which(fit1.JS>=15.5)
abs<-which(fit1.JS<15.5)
obs.pres<-which(obs.dat$pres>0)
obs.abs<-which(obs.dat$pres<=0)
mapPlot(coastlineWorldFine,projection="+proj=merc",col="lightgray",longitudelim=c(lonmin+1,lonmax-1),latitudelim=c(latmin+1,latmax-2),grid=FALSE,main="predicted GS")
mapPoints(lon.JS[pres], lat.JS[pres],pch=20,col="cornflowerblue")
mapPoints(lon.JS[abs], lat.JS[abs],pch=20,col="coral1")
mapPoints(obs.dat$lon[obs.pres], obs.dat$lat[obs.pres],col="deepskyblue4",cex=0.7)
mapPoints(obs.dat$lon[obs.abs], obs.dat$lat[obs.abs],col="coral4",cex=0.7)